﻿

# A4.Electric Field of a Dipole
# Greg Thompson
# 2/1/16
# Version 1

from __future__ import division
from visual import *

## constants
ke = 9e9 # Electrostatic Constant
qe = 1.6e-19  # proton charge
s = 4e-11    # charge separation
R = 3e-10  # display Enet on a circle of radius R
scalefactor = 1.0e-20 # for scaling arrows to represent electric field


## objects
## Represent the two charges of the dipole by red and blue spheres:
plus = sphere(pos=vector(s/2,0,0), radius=1e-11, color=color.red)
qplus = qe   # charge of positive particle
neg = sphere(pos=vector(-s/2,0,0), radius=1e-11, color=color.blue)
qneg = -qplus  # charge of negative particle


## calculations
theta = 0
while theta < 2*pi:
        rate(10)   
        ## Calculate observation location (tail of arrow) using current value of theta:
        Earrow = arrow(pos=R*vector(cos(theta),sin(theta),0), 
                axis=vector(1e-10,0,0), color=color.orange)

        Earrow2 = arrow(pos=R*vector(sin(theta),0,cos(theta)),axis=vector(1e-10,0,0),color=color.red)

        ## write instructions below to tell the computer how to calculate the correct 
        ## net electric field Enet at the observation location (the position of Earrow):
        r_plus = Earrow.pos-plus.pos
        r_pmag = mag(r_plus)
        r_p_hat = r_plus/r_pmag
        r_neg = Earrow.pos-neg.pos
        r_nmag = mag(r_neg)
        r_n_hat = r_neg/r_nmag
        e_net = (ke*(qplus/(r_pmag)**2)*r_p_hat) + (ke*(qneg/(r_nmag)**2)*r_n_hat)
        
        Earrow.axis = e_net*scalefactor

        print(r_plus)
        print(r_neg)
        print(e_net)

        r_plus2 = Earrow2.pos-plus.pos
        r_pmag2 = mag(r_plus2)
        r_p_hat2 = r_plus2/r_pmag2
        r_neg2 = Earrow2.pos-neg.pos
        r_nmag2 = mag(r_neg2)
        r_n_hat2 = r_neg2/r_nmag2
        e_net2 = (ke*(qplus/(r_pmag2)**2)*r_p_hat2) + (ke*(qneg/(r_nmag2)**2)*r_n_hat2)

        Earrow2.axis = e_net2*scalefactor

        print(r_plus2)
        print(r_neg2)
        print(e_net2) 

        

        ## change the axis of Earrow to point in the direction of the electric field at that location
        ## and scale it so it looks reasonable

        ## Assign a new value to theta
        theta = theta + pi/6
