from __future__ import division
from visual import *
scene.range = 6e-9
scene.width = 800
scene.height = 800

'''
Developed by Zakary T. Noel- February 2015
'''
def drawGrid():
    ##  CONSTANTS
    gridsep = griddim/gridscale
    ##  OBJECTS
    gridarea = box(pos=vector(0,0,0),height=griddim,length=griddim,width=1e-30,color=color.white)
    ## Lines...
    #Vertical
    xl = -griddim/2 + gridsep/2
    while xl < griddim/2:
        cyl = xl
        if cyl < gridsep and cyl > -gridsep:
            cylinder(pos=vector(xl,griddim/2,0),axis=vector(0,-griddim,0),radius=.2e-10,color=color.black)
        else:
            cylinder(pos=vector(xl,griddim/2,0),axis=vector(0,-griddim,0),radius=.2e-10,color=(.7,.7,.7))
        xl = xl + gridsep

    #Horizontal
    xl = -griddim/2 + gridsep/2
    while xl < griddim/2:
            cyl = xl
            if cyl < gridsep and cyl > -gridsep:
                cylinder(pos=vector(-griddim/2,xl,0),axis=vector(griddim,0,0),radius=.2e-10,color=color.black)
            else:
                cylinder(pos=vector(-griddim/2,xl,0),axis=vector(griddim,0,0),radius=.2e-10,color=(.7,.7,.7))
            xl = xl + gridsep
    

    
def drawEFieldVector(position):
    Earrow = arrow(pos=position, axis=vector(1e-10,0,0), color=color.orange)
    VLabel = label(pos = Earrow.pos)## write instructions below to tell the computer how to calculate the correct

    r1=Earrow.pos-plus.pos
    rmag1=sqrt(r1.x**2+r1.y**2+r1.z**2)
    rhat1 = (r1/rmag1)
    # 9e-9 * q Rhat / r^2
    E1 = (oofpez * (qplus/rmag1**2) * rhat1)
    Earrow.axis=E1*scalefactor
    V1 = (oofpez * (qplus/rmag1))

    r2=Earrow.pos-neg.pos
    rmag2=sqrt(r2.x**2+r2.y**2+r2.z**2)
    rhat2 = (r2/rmag2)
    E2 = (oofpez * (qneg/rmag2**2) * rhat2)
    Earrow.axis=E2*scalefactor
    V2 = (oofpez * (qneg/rmag2))
    

    Enet = E1 + E2
    Vnet = V1 + V2

    Earrow.axis=Enet*scalefactor
    VLabel.text = str(round(Vnet,3))

def drawEField():
    ## calculations
    theta = 0
    while theta < 2*pi:

        rate(10) # tell computer to go through loop slowly
        drawEFieldVector(R*vector(cos(theta),sin(theta),0)) #Draw the Efield Vector          
        theta = theta + pi/6

def drawCharges():
    plus = sphere(pos=vector(s/2,0,0), radius=1e-10, color=color.red)
    neg = sphere(pos=vector(-s/2,0,0), radius=1e-10, color=color.blue)
    return plus,neg

gridscale = 21 #An odd number will give a centered origin point
griddim = 1e-8
drawGrid()
##constants
oofpez = 9e9 # stands for One Over Four Pi Epsilon-Zero
qe = 1.6e-19 # proton charge
qplus = qe # charge of positive particle
qneg = -qplus # charge of negative particle
s = 4e-10 # charge separation
R = 3e-9 # display Enet on a circle of radius R
scalefactor = 2.0e-17 # for scaling arrows to represent electric field
resetButton = box(pos = vector(0,-griddim/2,0),text = 'RESET',size = (2*griddim/gridscale,griddim/gridscale,0))
resetButton.label = label(pos = resetButton.pos, text = 'RESET')
## objects
## Represent the two charges of the dipole by red and blue spheres:
plus,neg = drawCharges() 

drawEField()

try:
    while True:
        point = scene.mouse.getclick()
        if point.pick == resetButton or point.pick == resetButton.label:
            print "reset"
            for obj in scene.objects:
                obj.visible = 0
            drawGrid()
            drawCharges()
            
        else:
            drawEFieldVector(point.pos)
        
except KeyboardInterrupt:
    pass


#Clean everything up. 
print " Exit"

